==> syncthingtray_1.3.2.orig.tar.xz: syncthingtray-1.3.2/plasmoid/translations/syncthingplasmoid_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="98"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="75"/>
        <source>Show errors</source>
        <translation>Zobrazit chyby</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="86"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
        <source>Rescan</source>
        <translation>Znovu proskenovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="149"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="104"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="156"/>
        <source>Open in file browser</source>
        <translation>Otevřít ve správci souborů</translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="64"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="120"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="137"/>
        <source>Open in file browser</source>
        <translation>Otevřít ve správci souborů</translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="192"/>
        <source>Connect</source>
        <translation>Pripojit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="200"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="208"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="253"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="264"/>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="309"/>
        <source>Show new notifications</source>
        <translation>Zobrazit nová oznámení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="335"/>
        <source>Show own device ID</source>
        <translation>Zobrazit identifiktátor místního zařízení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="348"/>
        <source>Show Syncthing log</source>
        <translation>Zobrazit záznam událostí v Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="361"/>
        <source>Rescan all directories</source>
        <translation>Znovu proskenovat všechny adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="371"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="384"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="454"/>
        <source>Global</source>
        <translation>Globální</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="463"/>
        <source>Global incoming traffic</source>
        <translation>Globální příchozí provoz</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="474"/>
        <source>Local</source>
        <translation>Lokální</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="483"/>
        <source>Global outgoing traffic</source>
        <translation>Globální odchozí provoz</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="535"/>
        <source>Toggle filter</source>
        <translation>Vyp/zap. filtr</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="326"/>
        <source>About Syncthing Tray</source>
        <translation>O Syncthing Tray</translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="18"/>
        <source>Size of full representation</source>
        <translation>Velikost úplného zobrazení</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="68"/>
        <source> x </source>
        <translation> x </translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="94"/>
        <source> grid units</source>
        <translation> jednotek mřížky</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="112"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop, in full screen mode or as entry of the system tray Plasmoid.</source>
        <translation>Poznamenejme, že velikost je ignorována pokud je Plasmoid zobrazován na ploše, v režimu na celou obrazovku nebo jako položka plasmoidu v systémové oznamovací oblasti.</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="124"/>
        <source>States to enable passive mode</source>
        <translation>Stavy pro zapnutí pasivního režimu</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="32"/>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation>Světlé uživatelsky určené barvy textu (použijte pro tmavé schéma barev)</translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation>Nastavení na této stránce jsou specifická stávající instanci plasmoidu.</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="126"/>
        <source>Plasmoid</source>
        <translation>Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="134"/>
        <source>Web view</source>
        <translation>Webové zobrazení</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="144"/>
        <source>Extras</source>
        <translation>Další</translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation>Globales zkratky</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="324"/>
        <source>About</source>
        <translation>O Syncthing Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="336"/>
        <source>New notifications</source>
        <translation>Nová oznámení</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="491"/>
        <source>D-Bus error - unable to </source>
        <translation>chyba D-Bus – nedaří </translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="15"/>
        <source> files</source>
        <translation> soubory</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="20"/>
        <source> directories</source>
        <translation> adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="26"/>
        <source> size</source>
        <translation> velikost</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="58"/>
        <source>Web UI</source>
        <translation>Webové rozhraní</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="59"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="60"/>
        <source>Log</source>
        <translation>Záznam událostí</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="62"/>
        <source>Internal errors</source>
        <translation>Vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="64"/>
        <source>Rescan all directories</source>
        <translation>Znovu proskenovat všechny adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="66"/>
        <source>Restart Syncthing</source>
        <translation>Restartovat Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="68"/>
        <source>About</source>
        <translation>O Syncthing Plasmoid</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.4.12.orig.tar.xz: syncthingtray-1.4.12/plasmoid/translations/syncthingplasmoid_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DetailView</name>
    <message>
        <location filename="../package/contents/ui/DetailView.qml" line="14"/>
        <source>Copy value</source>
        <translation>Zkopírovat hodnotu</translation>
    </message>
</context>
<context>
    <name>DevicesPage</name>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
        <location filename="../package/contents/ui/DevicesPage.qml" line="98"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
</context>
<context>
    <name>DirectoriesPage</name>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="75"/>
        <source>Show errors</source>
        <translation>Zobrazit chyby</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="86"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
        <source>Rescan</source>
        <translation>Znovu proskenovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="149"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="104"/>
        <location filename="../package/contents/ui/DirectoriesPage.qml" line="156"/>
        <source>Open in file browser</source>
        <translation>Otevřít ve správci souborů</translation>
    </message>
</context>
<context>
    <name>DownloadsPage</name>
    <message>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="64"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="120"/>
        <location filename="../package/contents/ui/DownloadsPage.qml" line="137"/>
        <source>Open in file browser</source>
        <translation>Otevřít ve správci souborů</translation>
    </message>
</context>
<context>
    <name>FullRepresentation</name>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="192"/>
        <source>Connect</source>
        <translation>Pripojit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="200"/>
        <source>Resume</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="208"/>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="253"/>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="264"/>
        <source>Start</source>
        <translation>Spustit</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="309"/>
        <source>Show new notifications</source>
        <translation>Zobrazit nová oznámení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="335"/>
        <source>Show own device ID</source>
        <translation>Zobrazit identifiktátor místního zařízení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="348"/>
        <source>Show Syncthing log</source>
        <translation>Zobrazit záznam událostí v Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="361"/>
        <source>Rescan all folders</source>
        <translation>Znovu proskenovat všechny adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="371"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="384"/>
        <source>Open Syncthing</source>
        <translation>Otevřít Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="454"/>
        <source>Global</source>
        <translation>Globální</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="463"/>
        <source>Global incoming traffic</source>
        <translation>Globální příchozí provoz</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="474"/>
        <source>Local</source>
        <translation>Lokální</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="483"/>
        <source>Global outgoing traffic</source>
        <translation>Globální odchozí provoz</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="535"/>
        <source>Toggle filter</source>
        <translation>Vyp/zap. filtr</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/FullRepresentation.qml" line="326"/>
        <source>About Syncthing Tray</source>
        <translation>O Syncthing Tray</translation>
    </message>
</context>
<context>
    <name>Plasmoid::AppearanceOptionPage</name>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="18"/>
        <source>Size of full representation</source>
        <translation>Velikost úplného zobrazení</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="68"/>
        <source> x </source>
        <translation> x </translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="94"/>
        <source> grid units</source>
        <translation> jednotek mřížky</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="112"/>
        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop, in full screen mode or as entry of the system tray Plasmoid.</source>
        <translation>Poznamenejme, že velikost je ignorována pokud je Plasmoid zobrazován na ploše, v režimu na celou obrazovku nebo jako položka plasmoidu v systémové oznamovací oblasti.</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="124"/>
        <source>States to enable passive mode</source>
        <translation>Stavy pro zapnutí pasivního režimu</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../lib/appearanceoptionpage.ui" line="32"/>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation>Světlé uživatelsky určené barvy textu (použijte pro tmavé schéma barev)</translation>
    </message>
</context>
<context>
    <name>Plasmoid::Settings</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="29"/>
        <source>The settings on this page are specific to the current instance of the Plasmoid.</source>
        <translation>Nastavení na této stránce jsou specifická stávající instanci plasmoidu.</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SettingsDialog</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="126"/>
        <source>Plasmoid</source>
        <translation>Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="134"/>
        <source>Web view</source>
        <translation>Webové zobrazení</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="144"/>
        <source>Extras</source>
        <translation>Další</translation>
    </message>
</context>
<context>
    <name>Plasmoid::ShortcutOptionPage</name>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="66"/>
        <source>Shortcuts</source>
        <translation>Klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../lib/settingsdialog.cpp" line="72"/>
        <source>Global shortcut</source>
        <translation>Globales zkratky</translation>
    </message>
</context>
<context>
    <name>Plasmoid::SyncthingApplet</name>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="324"/>
        <source>About</source>
        <translation>O Syncthing Plasmoid</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="336"/>
        <source>New notifications</source>
        <translation>Nová oznámení</translation>
    </message>
    <message>
        <location filename="../lib/syncthingapplet.cpp" line="491"/>
        <source>D-Bus error - unable to </source>
        <translation>chyba D-Bus – nedaří </translation>
    </message>
</context>
<context>
    <name>StatisticsView</name>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="15"/>
        <source> files</source>
        <translation> soubory</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="20"/>
        <source> directories</source>
        <translation> adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/StatisticsView.qml" line="26"/>
        <source> size</source>
        <translation> velikost</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../package/contents/ui/main.qml" line="58"/>
        <source>Web UI</source>
        <translation>Webové rozhraní</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="59"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="60"/>
        <source>Log</source>
        <translation>Záznam událostí</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="62"/>
        <source>Internal errors</source>
        <translation>Vnitřní chyby</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="64"/>
        <source>Rescan all folders</source>
        <translation>Znovu proskenovat všechny adresáře</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="66"/>
        <source>Restart Syncthing</source>
        <translation>Restartovat Syncthing</translation>
    </message>
    <message>
        <location filename="../package/contents/ui/main.qml" line="68"/>
        <source>About</source>
        <translation>O Syncthing Plasmoid</translation>
    </message>
</context>
</TS>
